@@ -49,9 +49,9 @@ function (x=mycor,
          col.fill=getOption("col.fill.pt"),
          shape.pts=21, col.grid=getOption("col.grid"),
          col.bg=getOption("col.bg"),
-         cex.axis=.85, col.axis="gray30",
+         cex.axis=.85, col.axis="gray30", rotate.values=0, offset=0.5,
          xy.ticks=TRUE, line.width=1.1,
-         xlab=NULL, ylab="Eigenvalues", main=main, cex=NULL,
+         xlab=NULL, ylab="Eigenvalues", main=main, sub=NULL, cex=NULL,
          x.start=NULL, x.end=NULL, y.start=NULL, y.end=NULL,
          time.start=NULL, time.by=NULL, time.reverse=FALSE,
          center.line="off", quiet=TRUE, ...)
@@ -84,10 +84,10 @@ function (x=mycor,
          col.fill=getOption("col.fill.pt"),
          shape.pts=21, col.grid=getOption("col.grid"),
          col.bg=getOption("col.bg"),
-         cex.axis=.85, col.axis="gray30",
+         cex.axis=.85, col.axis="gray30", rotate.values=0, offset=0.5,
          xy.ticks=TRUE, line.width=1.1,
          xlab=NULL, ylab="Differences of Successive Eigenvalues",
-         main=main, cex=NULL,
+         main=main, sub=NULL, cex=NULL,
          x.start=NULL, x.end=NULL, y.start=NULL, y.end=NULL,
          time.start=NULL, time.by=NULL, time.reverse=FALSE,
          center.line="off", quiet=TRUE, ...)
