@@ -8,7 +8,7 @@ function(x, col.fill, col.stroke, col.bg, col.grid,
 
 
   # scale for regular R or RStudio
-  adj <- .RSadj(bubble.size=NULL, cex.axis)
+  adj <- .RSadj(bubble.scale=NULL, cex.axis)
   size.axis <- adj$size.axis
   size.lab <- adj$size.lab
 
